[![Build Status](https://travis-ci.org/abn/cafeteria-asyncio.svg?branch=master)](https://travis-ci.org/abn/cafeteria-asyncio)
[![image](https://img.shields.io/pypi/v/cafeteria-asyncio.svg)](https://pypi.org/project/cafeteria-asyncio/)
[![image](https://img.shields.io/pypi/l/cafeteria-asyncio.svg)](https://pypi.org/project/cafeteria-asyncio/)
[![image](https://img.shields.io/pypi/pyversions/cafeteria-asyncio.svg)](https://pypi.org/project/cafeteria-asyncio/)
[![image](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)

# Asyncio Patterns and Utilities
An extension to the cafeteria package to enable asyncio specific patterns for python 3.7 and above applications/libraries.

## Installation
`pip install cafeteria-asyncio`
